<?php
/* -----------------------------------------------------------------------------------------
   $Id: eps2.php,v 1.0 2019/09/19 01:43:00 fanta2k Exp $

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   -----------------------------------------------------------------------------------------
   Third Party contributions:
   EPS2 v1.0                       Autor:   Ludwig Ertl  <ludwig.ertl@softwerker.at>

   Released under the GNU General Public License
   ---------------------------------------------------------------------------------------*/

  define('MODULE_PAYMENT_EPS2_TEXT_TITLE', 'EPS 2');
  define('MODULE_PAYMENT_EPS2_TEXT_DESCRIPTION', 'Electronic Payment System');
  define('MODULE_PAYMENT_EPS2_STATUS_TITLE','EPS2 Modul aktivieren');
  define('MODULE_PAYMENT_EPS2_STATUS_DESC','M&ouml;chten Sie Zahlungen via EPS akzeptieren?');
  define('MODULE_PAYMENT_EPS2_USERID_TITLE','H&auml;ndlerID');
  define('MODULE_PAYMENT_EPS2_USERID_DESC','Die Ihnen von der Bank zugewiesene H&auml;ndlerID');
  define('MODULE_PAYMENT_EPS2_PWD_TITLE','PIN');
  define('MODULE_PAYMENT_EPS2_PWD_DESC','Geben Sie Ihren EPS-PIN ein (dieses ist notwendig, un die Transaktion durchzuf&uuml;hren!)');
  define('MODULE_PAYMENT_EPS2_LANGUAGE_TITLE','Transaktionssprache');
  define('MODULE_PAYMENT_EPS2_LANGUAGE_DESC','Die Sprache für die Zahlungstransaktion.');
  define('MODULE_PAYMENT_EPS2_HBES1_TITLE','Best&auml;tigungsmeldung');
  define('MODULE_PAYMENT_EPS2_HBES1_DESC','Bestaetigungsmeldung, die nach em Abschicken der Bestellung angezeigt werden soll.');
  define('MODULE_PAYMENT_EPS2_TESTSYSTEM_TITLE','Testsystem benutzen?');
  define('MODULE_PAYMENT_EPS2_TESTSYSTEM_DESC','M&ouml;chten Sie das Testsystem statt der Produktionsumgebung nutzen?');
  define('MODULE_PAYMENT_EPS2_BANK_TITLE', 'Bankserver');
  define('MODULE_PAYMENT_EPS2_BANK_DESC', 'Bank &uuml;ber die die Transaktionen abgewickelt werden.');
  define('MODULE_PAYMENT_EPS2_ORDER_TEXT', 'Bestelldatum ');
  define('MODULE_PAYMENT_EPS2_IBAN_TITLE', 'IBAN');
  define('MODULE_PAYMENT_EPS2_IBAN_DESC', 'IBAN des Beg&uuml;nstigten');
  define('MODULE_PAYMENT_EPS2_BIC_TITLE', 'BIC');
  define('MODULE_PAYMENT_EPS2_BIC_DESC', 'BIC des Beg&uuml;nstigten');
  define('MODULE_PAYMENT_EPS2_ORDER_STATUS_ID_TITLE', 'Bestellstatus festlegen');
  define('MODULE_PAYMENT_EPS2_ORDER_STATUS_ID_DESC', 'Bestellungen, welche mit diesem Modul gemacht werden, auf diesen Status setzen');
  define('MODULE_PAYMENT_EPS2_SORT_ORDER_TITLE' , 'Anzeigereihenfolge');
  define('MODULE_PAYMENT_EPS2_SORT_ORDER_DESC' , 'Reihenfolge der Anzeige. Kleinste Ziffer wird zuerst angezeigt.');
  define('MODULE_PAYMENT_EPS2_ZONE_TITLE','Zahlungszone');
  define('MODULE_PAYMENT_EPS2_ZONE_DESC','Wenn eine Zone ausgew&auml;hlt ist, gilt die Zahlungsmethode nur f&uuml;r diese Zone.');
  define('MODULE_PAYMENT_EPS2_TEXT_BANK', 'Bankinstitut:');
  define('MODULE_PAYMENT_EPS2_CONFIRMATION_TEXT', 'Danke f&uuml;r Ihre Bestellung!');
  define('MODULE_PAYMENT_EPS2_TEXT_EMAIL_FOOTER', 'Vielen Dank fuer Ihre Bestellung!');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR_NOBIC', 'Kein BIC in Konfiguration angegeben, Konfiguration fehlerhaft');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR_NOIBAN', 'Kein IBAN in Konfiguration angegeben, Konfiguration fehlerhaft');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR', 'Fehler bei Zahlung!');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR1', 'Der Händlerserver konnte bei der Übermittlung der Zahlungsbestätigung nicht erreicht werden.<br>Versuchen Sie es evtl. etwas später nochmals.');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR2', 'Der XML-Strom war ungültig oder die Signatur defekt. Bitte setzen Sie den Händler davon in Kenntnis.');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR3', 'Sie haben die Zahlung abgebrochen. Ihre Bestellung wurde nicht durchgeführt!');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR_NO_REPLY', 'Keine Rückmeldung des Bankservers empfangen');
  ?>