<?php
/* -----------------------------------------------------------------------------------------
   $Id: eps2.php,v 1.0 2019/09/19 01:43:00 fanta2k Exp $

   XT-Commerce - community made shopping
   http://www.xt-commerce.com

   Copyright (c) 2003 XT-Commerce
   -----------------------------------------------------------------------------------------
   Third Party contributions:
   EPS2 v1.0                       Autor:   Ludwig Ertl  <ludwig.ertl@softwerker.at>

   Released under the GNU General Public License
   ---------------------------------------------------------------------------------------*/

  define('MODULE_PAYMENT_EPS2_TEXT_TITLE', 'EPS 2');
  define('MODULE_PAYMENT_EPS2_TEXT_DESCRIPTION', 'Electronic Payment System');
  define('MODULE_PAYMENT_EPS2_STATUS_TITLE','activate EPS1 module?');
  define('MODULE_PAYMENT_EPS2_STATUS_DESC','Would you like to accept payment via EPS?');
  define('MODULE_PAYMENT_EPS2_USERID_TITLE','UserID');
  define('MODULE_PAYMENT_EPS2_USERID_DESC','The UserID you received from your bank');
  define('MODULE_PAYMENT_EPS2_PWD_TITLE','PIN');
  define('MODULE_PAYMENT_EPS2_PWD_DESC','Please enter your EPS-PIN (this is necessary in order to make transactions)');
  define('MODULE_PAYMENT_EPS2_LANGUAGE_TITLE','Transaction language');
  define('MODULE_PAYMENT_EPS2_LANGUAGE_DESC','The language that is used for the transaction.');
  define('MODULE_PAYMENT_EPS2_HBES1_TITLE','Confirmation message');
  define('MODULE_PAYMENT_EPS2_HBES1_DESC','Message to show after confirmation of the transaction.');
  define('MODULE_PAYMENT_EPS2_TESTSYSTEM_TITLE','Use test-system?');
  define('MODULE_PAYMENT_EPS2_TESTSYSTEM_DESC','Would you like to use the test environment instead of the production system?');
  define('MODULE_PAYMENT_EPS2_BANK_TITLE', 'Bank server');
  define('MODULE_PAYMENT_EPS2_BANK_DESC', 'Choose your bank.');
  define('MODULE_PAYMENT_EPS2_ORDER_TEXT', 'Date of order: ');
  define('MODULE_PAYMENT_EPS2_IBAN_TITLE', 'IBAN');
  define('MODULE_PAYMENT_EPS2_IBAN_DESC', "Beneficiary's IBAN");
  define('MODULE_PAYMENT_EPS2_BIC_TITLE', 'BIC');
  define('MODULE_PAYMENT_EPS2_BIC_DESC', "Beneficiary's BIC");
  define('MODULE_PAYMENT_EPS2_TEXT_BANK', 'Bank:');
  define('MODULE_PAYMENT_EPS2_ORDER_STATUS_ID_TITLE', 'Order status after completion');
  define('MODULE_PAYMENT_EPS2_ORDER_STATUS_ID_DESC', 'Set orders that are successfully ordered with this payment module to the given state.');
  define('MODULE_PAYMENT_EPS2_SORT_ORDER_TITLE','Sort order of display.');
  define('MODULE_PAYMENT_EPS2_SORT_ORDER_DESC','Sort order of display. Lowest is displayed first.');
  define('MODULE_PAYMENT_EPS2_ZONE_TITLE','Payment Zone');
  define('MODULE_PAYMENT_EPS2_ZONE_DESC','If a zone is selected, only enable this payment method for that zone.');
  define('MODULE_PAYMENT_EPS2_CONFIRMATION_TEXT', 'Thank you for your order!');
  define('MODULE_PAYMENT_EPS2_TEXT_EMAIL_FOOTER', 'Thank you for your order!');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR_NOBIC', 'No BIC set in configuration, configuration invalid');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR_NOIBAN', 'No IBAN set in configuration, configuration invalid');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR', 'Payment error!');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR1', 'Our server cannot be reached to send the payment confirmation.<br>Please try again a little later.');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR2', 'The XML-stream was invalid or the signature was defective. Please inform the shop-owner.');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR3', 'You cancelled the transaction. Therefore your order cannot be processed!');
  define('MODULE_PAYMENT_EPS2_TEXT_ERROR_NO_REPLY', 'No reply received from the banking application server.');
  ?>